@@ -7,8 +7,6 @@ mod adb_tcp_connexion;
 mod adb_termios;
 mod error;
 mod models;
-mod traits;
 pub use adb_tcp_connexion::AdbTcpConnexion;
 pub use error::{Result, RustADBError};
 pub use models::{AdbVersion, Device, DeviceLong, DeviceState};
-pub use traits::AdbCommandProvider;
